@@ -25,7 +25,7 @@ from adam.commands.restart import Restart
 from adam.commands.rollout import RollOut
 from adam.commands.show.show import Show, ShowCommandHelper
 from adam.commands.watch import Watch
-from adam.k8s_utils.kube_context import KubeContext
+from adam.utils_k8s.kube_context import KubeContext
 from adam.repl import enter_repl
 from adam.repl_state import ReplState
 from adam.cli_group import cli
