@@ -1,6 +1,7 @@
 from adam.commands.command import Command
-from adam.k8s_utils.cassandra_clusters import CassandraClusters
-from adam.k8s_utils.cassandra_nodes import CassandraNodes
+from adam.utils_k8s.cassandra_clusters import CassandraClusters
+from adam.utils_k8s.cassandra_nodes import CassandraNodes
+from adam.pod_exec_result import PodExecResult
 from adam.repl_state import BashSession, ReplState, RequiredState
 
 class Bash(Command):
@@ -25,12 +26,16 @@ class Bash(Command):
         if not(args := self.args(cmd)):
             return super().run(cmd, s0)
 
-        state, args = self.apply_state(args, s0)
+        state, args = self.apply_state(args, s0, args_to_check=2)
         if not self.validate_state(state):
             return state
 
         if state.in_repl:
-            r = self.exec_with_dir(s0, args)
+            if s0.sts != state.sts or s0.pod != state.pod:
+                r = self.exec_with_dir(state, args)
+            else:
+                r = self.exec_with_dir(s0, args)
+
             if not r:
                 state.exit_bash()
 
@@ -38,8 +43,7 @@ class Bash(Command):
 
             return r
         else:
-            a = ' '.join(args)
-            command = f'bash -c "{a}"'
+            command = ' '.join(args)
 
             if state.pod:
                 CassandraNodes.exec(state.pod, state.namespace, command, show_out=True)
@@ -48,7 +52,7 @@ class Bash(Command):
 
             return state
 
-    def exec_with_dir(self, state: ReplState, args: list[str]):
+    def exec_with_dir(self, state: ReplState, args: list[str]) -> list[PodExecResult]:
         session_just_created = False
         if not args:
             session_just_created = True
@@ -65,15 +69,16 @@ class Bash(Command):
                 if pwd := state.bash_session.pwd(state):
                     args = ['cd', pwd, '&&'] + args
 
-        a = ' '.join(args)
-        command = f'bash -c "{a}"'
+        command = ' '.join(args)
 
         rs = []
 
         if state.pod:
-            rs = [CassandraNodes.exec(state.pod, state.namespace, command, show_out=not session_just_created)]
+            rs = [CassandraNodes.exec(state.pod, state.namespace, command,
+                                      show_out=not session_just_created, shell='bash')]
         elif state.sts:
-            rs = CassandraClusters.exec(state.sts, state.namespace, command, action='bash', show_out=not session_just_created)
+            rs = CassandraClusters.exec(state.sts, state.namespace, command, action='bash',
+                                        show_out=not session_just_created, shell='bash')
 
         return rs
 
