@@ -53,8 +53,8 @@ class Command:
 
         return a
 
-    def apply_state(self, args: list[str], state: ReplState, resolve_pg = True) -> tuple[ReplState, list[str]]:
-        return state.apply_args(args, cmd=self.command_tokens(), resolve_pg=resolve_pg)
+    def apply_state(self, args: list[str], state: ReplState, resolve_pg = True, args_to_check = 6) -> tuple[ReplState, list[str]]:
+        return state.apply_args(args, cmd=self.command_tokens(), resolve_pg=resolve_pg, args_to_check=args_to_check)
 
     def command_tokens(self):
         return self.command().split(' ')
