@@ -35,4 +35,4 @@ class DeployPgAgent(Command):
         return super().completion(state)
 
     def help(self, _: ReplState):
-        return f'{DeployPgAgent.COMMAND}\t deploy postgres agent'
\ No newline at end of file
+        return f'{DeployPgAgent.COMMAND}\t deploy Postgres agent'
\ No newline at end of file
