@@ -1,6 +1,6 @@
 from adam.commands.command import Command
 from adam.config import Config
-from adam.k8s_utils.cassandra_nodes import CassandraNodes
+from adam.utils_k8s.cassandra_nodes import CassandraNodes
 from adam.repl_state import ReplState, RequiredState
 
 class Logs(Command):
