@@ -1,10 +1,11 @@
 import functools
 
 from adam.commands.command import Command
-from adam.commands.cql_utils import run_cql, tables
+from adam.commands.cql.cql_table_completer import CqlTableNameCompleter
+from adam.commands.cql.cql_utils import run_cql, table_names, tables
 from adam.commands.postgres.postgres_session import PostgresSession
+from adam.commands.postgres.psql_table_completer import PsqlTableNameCompleter
 from adam.config import Config
-from adam.pod_exec_result import PodExecResult
 from adam.repl_state import ReplState, RequiredState
 from adam.utils import lines_to_tabular, log, log2
 
@@ -72,11 +73,9 @@ class PreviewTable(Command):
 
     def completion(self, state: ReplState):
         if state.device == ReplState.P:
-            if tables := PreviewTable.pg_tables(state.namespace, state.pg_path):
-                return {PreviewTable.COMMAND: {db["name"]: None for db in tables if db["schema"] == PostgresSession.default_schema()}}
+            return {PreviewTable.COMMAND: PsqlTableNameCompleter(state.namespace, state.pg_path)}
         elif state.sts:
-            tables = PreviewTable.cql_tables(state)
-            return {PreviewTable.COMMAND: {f'{k}.{t}': None for k, ts in tables.items() for t in ts}}
+            return {PreviewTable.COMMAND: CqlTableNameCompleter(table_names(state))}
 
         return {}
 
@@ -88,18 +87,4 @@ class PreviewTable(Command):
         if state.pod:
             return tables(state)
 
-        return tables(state, on_any=True)
-
-        # r: list[PodExecResult] = run_cql(state, 'describe tables', show_out=False, on_any=True)
-        # if not r:
-        #     return []
-
-        # return parse_cql_desc_tables(r[0].stdout)
-
-    @functools.lru_cache()
-    def pg_tables(ns: str, pg_path: str):
-        pg = PostgresSession(ns, pg_path)
-        if pg.db:
-            return pg.tables()
-
-        return None
+        return tables(state, on_any=True)
\ No newline at end of file
