@@ -40,6 +40,8 @@ class Pwd(Command):
                     words.append(f'env/{state.app_env}')
                 if state.app_app:
                     words.append(f'app/{state.app_app}')
+            elif device == ReplState.L:
+                pass
             else:
                 if state.sts:
                     words.append(f'sts/{state.sts}')
@@ -58,6 +60,7 @@ class Pwd(Command):
         log(lines_to_tabular([
             device_line(state, ReplState.A),
             device_line(state, ReplState.C),
+            device_line(state, ReplState.L),
             device_line(state, ReplState.P),
             f'',
             f'HOST\t{host}',
