@@ -1,5 +1,5 @@
 from adam.commands.command import Command
-from adam.k8s_utils.jobs import Jobs
+from adam.utils_k8s.jobs import Jobs
 from adam.repl_state import ReplState, RequiredState
 
 class RepairLog(Command):
