@@ -1,7 +1,7 @@
 import time
 
 from adam.commands.command import Command
-from adam.k8s_utils.pods import Pods
+from adam.utils_k8s.pods import Pods
 from adam.repl_state import ReplState, RequiredState
 from adam.utils import log2
 from adam.config import Config
