@@ -1,3 +1,4 @@
+import os
 from typing import TypeVar, cast
 import yaml
 
@@ -38,7 +39,7 @@ class Config:
         return get_deep_keys(self.params)
 
     def is_debug(self):
-        return Config().get('debug', False)
+        return os.getenv('QING_DEV').lower() == 'true' or Config().get('debug', False)
 
     def debug(self, s: None):
         if self.is_debug():
