@@ -15,12 +15,14 @@ class PodExecResult:
     #     ]
     #   }
     # }
-    def __init__(self, stdout: str, stderr: str, command: str = None, error_output: str = None):
+    def __init__(self, stdout: str, stderr: str, command: str = None, error_output: str = None, pod: str = None, log_file: str = None):
         self.stdout: str = stdout
         self.stderr: str = stderr
         self.command: str = command
         if error_output:
             self.error = yaml.safe_load(error_output)
+        self.pod = pod
+        self.log_file = log_file
 
     def exit_code(self) -> int:
         code = 0
