@@ -1,6 +1,6 @@
 from typing import Callable, Iterable, List, Mapping, Optional, Pattern, Union
 
-from prompt_toolkit.completion import CompleteEvent, Completer, Completion, WordCompleter
+from prompt_toolkit.completion import CompleteEvent, Completion, WordCompleter
 from prompt_toolkit.document import Document
 from prompt_toolkit.formatted_text import AnyFormattedText
 
